Welcome to mirror list, hosted at ThFree Co, Russian Federation.

cygwin.com/git/newlib-cygwin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'include/elf')
-rw-r--r--include/elf/ChangeLog23
-rw-r--r--include/elf/tic6x-attrs.h12
-rw-r--r--include/elf/tic6x.h18
3 files changed, 10 insertions, 43 deletions
diff --git a/include/elf/ChangeLog b/include/elf/ChangeLog
index 39de1ff9f..61bbf81db 100644
--- a/include/elf/ChangeLog
+++ b/include/elf/ChangeLog
@@ -1,26 +1,3 @@
-2010-11-02 Joseph Myers <joseph@codesourcery.com>
-
- * tic6x-attrs.h (Tag_ABI_wchar_t, Tag_ABI_stack_align_needed,
- Tag_ABI_stack_align_preserved, Tag_ABI_PID, Tag_ABI_PIC,
- Tag_ABI_array_object_alignment,
- Tag_ABI_array_object_align_expected, Tag_ABI_conformance): Define.
-
-2010-10-29 Joseph Myers <joseph@codesourcery.com>
-
- * tic6x-attrs.h (Tag_ABI_compatibility): Define.
-
-2010-10-29 Bernd Schmidt <bernds@codesourcery.com>
- Joseph Myers <joseph@codesourcery.com>
-
- * tic6x-attrs.h (Tag_ABI_DSBT): New.
-
-2010-10-21 Joseph Myers <joseph@codesourcery.com>
-
- * tic6x-attrs.h (Tag_C6XABI_Tag_CPU_arch): Change to Tag_ISA,
- value 4.
- * tic6x.h (Values for Tag_C6XABI_Tag_CPU_arch): Rename for
- attribute renaming.
-
2010-07-23 Naveen.H.S <naveen.S@kpitcummins.com>
Ina Pandit <ina.pandit@kpitcummins.com>
diff --git a/include/elf/tic6x-attrs.h b/include/elf/tic6x-attrs.h
index 21ce1e4f5..d5b8ee1ae 100644
--- a/include/elf/tic6x-attrs.h
+++ b/include/elf/tic6x-attrs.h
@@ -22,14 +22,4 @@
/* Define the TAG macro before including this file; it takes a tag
name and value. */
-TAG(Tag_ISA, 4)
-TAG(Tag_ABI_wchar_t, 6)
-TAG(Tag_ABI_stack_align_needed, 8)
-TAG(Tag_ABI_stack_align_preserved, 10)
-TAG(Tag_ABI_DSBT, 12)
-TAG(Tag_ABI_PID, 14)
-TAG(Tag_ABI_PIC, 16)
-TAG(Tag_ABI_array_object_alignment, 18)
-TAG(Tag_ABI_array_object_align_expected, 20)
-TAG(Tag_ABI_compatibility, 32)
-TAG(Tag_ABI_conformance, 67)
+TAG(Tag_C6XABI_Tag_CPU_arch, 2)
diff --git a/include/elf/tic6x.h b/include/elf/tic6x.h
index 88000fa1a..a9b66ddf3 100644
--- a/include/elf/tic6x.h
+++ b/include/elf/tic6x.h
@@ -134,17 +134,17 @@ enum
Tag_C6XABI_last
};
-/* Values for Tag_ISA. GNU-specific names; the ABI does not specify
- names for these values. */
+/* Values for Tag_C6XABI_Tag_CPU_arch. GNU-specific names pending any
+ ABI defining official names associated with the values. */
enum
{
- C6XABI_Tag_ISA_none = 0,
- C6XABI_Tag_ISA_C62X = 1,
- C6XABI_Tag_ISA_C67X = 3,
- C6XABI_Tag_ISA_C67XP = 4,
- C6XABI_Tag_ISA_C64X = 6,
- C6XABI_Tag_ISA_C64XP = 7,
- C6XABI_Tag_ISA_C674X = 8
+ C6XABI_Tag_CPU_arch_none = 0,
+ C6XABI_Tag_CPU_arch_C62X = 1,
+ C6XABI_Tag_CPU_arch_C67X = 3,
+ C6XABI_Tag_CPU_arch_C67XP = 4,
+ C6XABI_Tag_CPU_arch_C64X = 6,
+ C6XABI_Tag_CPU_arch_C64XP = 7,
+ C6XABI_Tag_CPU_arch_C674X = 8
};
#endif /* _ELF_TIC6X_H */